@@ -12,6 +12,17 @@
 #include <net/if.h>
 
 
+static int ifconfig_ioctl(
+	int fd,
+	const char *ifname,
+	int cmd,
+	struct ifreq *ifr)
+{
+	strcpy(ifr->ifr_name, ifname);
+	return ioctl(fd, cmd,ifr);
+}
+
+
 static int devlist_read2_2()
 {
 	int ret = -1;
@@ -44,11 +55,22 @@ static int devlist_read2_2()
 			for (int n = 0; n < ifc.ifc_len; n += sizeof(struct ifreq)) {
 				struct sockaddr_in *sin = (struct sockaddr_in*)&ifr->ifr_addr;
 				unsigned long addr = ntohl(sin->sin_addr.s_addr);
-				printf ("%lu.%lu.%lu.%lu\n"
+				unsigned long mask = 0xffffff00;
+				struct ifreq ifmask;
+				if (ifconfig_ioctl(skfd,ifr->ifr_name,SIOCGIFNETMASK, &ifmask) >= 0){
+					struct sockaddr_in *sin = (struct sockaddr_in*)&ifmask.ifr_addr;
+					mask = ntohl(sin->sin_addr.s_addr);
+				}
+
+				printf ("%lu.%lu.%lu.%lu/%lu.%lu.%lu.%lu\n"
 					,(addr>>24)&0xff
 					,(addr>>16)&0xff
 					,(addr>>8)&0xff
-					,addr&0xff);
+					,addr&0xff
+					,(mask>>24)&0xff
+					,(mask>>16)&0xff
+					,(mask>>8)&0xff
+					,mask&0xff);
 				ifr++;
 			}
 		}
